==> igniteui-angular-charts-18.2.0.tgz: package/esm2015/lib/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let BollingerBandWidthIndicator = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicator extends StrategyBasedIndicator {
        bj() {
            return new BollingerBandWidthIndicator();
        }
        get_abv() {
            return new BollingerBandWidthIndicatorStrategy();
        }
        get abv() {
            return this.get_abv();
        }
        get_ab8() {
            return BollingerBandWidthIndicator.$;
        }
        get ab8() {
            return this.get_ab8();
        }
        get ach() {
            return typeGetValue(this.c(BollingerBandWidthIndicator.ack));
        }
        set ach(a) {
            this.h(BollingerBandWidthIndicator.ack, a);
        }
        ab1() {
            return this.ach;
        }
        get acg() {
            return this.c(BollingerBandWidthIndicator.acj);
        }
        set acg(a) {
            this.h(BollingerBandWidthIndicator.acj, a);
        }
        abz() {
            return this.acg;
        }
    }
    BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.ack = StrategyBasedIndicator.acd(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.acj = StrategyBasedIndicator.acc(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
})();

==> igniteui-angular-charts-20.0.0.tgz: package/esm2015/lib/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let BollingerBandWidthIndicator = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicator extends StrategyBasedIndicator {
        bk() {
            return new BollingerBandWidthIndicator();
        }
        get_ab0() {
            return new BollingerBandWidthIndicatorStrategy();
        }
        get ab0() {
            return this.get_ab0();
        }
        get_acd() {
            return BollingerBandWidthIndicator.$;
        }
        get acd() {
            return this.get_acd();
        }
        get acm() {
            return typeGetValue(this.c(BollingerBandWidthIndicator.acp));
        }
        set acm(a) {
            this.h(BollingerBandWidthIndicator.acp, a);
        }
        ab6() {
            return this.acm;
        }
        get acl() {
            return this.c(BollingerBandWidthIndicator.aco);
        }
        set acl(a) {
            this.h(BollingerBandWidthIndicator.aco, a);
        }
        ab4() {
            return this.acl;
        }
    }
    BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.acp = StrategyBasedIndicator.aci(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.aco = StrategyBasedIndicator.ach(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
})();
